@@ -1,7 +1,6 @@
 import logging
 from functools import reduce
 from itertools import groupby
-from types import NoneType
 from typing import List, Dict, Union
 
 
@@ -26,7 +25,7 @@ def remove_list_dict_duplicate(list_dict_data):
     return reduce(lambda x, y: x if y in x else x + [y], [[], ] + list_dict_data)
 
 
-def retry(func, params: Union[dict, list, tuple, NoneType], check_func, num=1):
+def retry(func, params: Union[dict, list, tuple], check_func, num=1):
     """
     执行失败重试
     :param func: 要执行的函数
